HtmlMetaParser class

Takes a Document and parses OpengraphMetadata from <meta>, <title> and <img> tags

Mixed-in types

Constructors

HtmlMetaParser(Document? _document)

Properties

description String?
Get the OpengraphMetadata.description from the <meta name="description"> tag
getter/setter pairinherited-setteroverride-getter
hashCode int
The hash code for this object.
no setterinherited
image String?
Get the OpengraphMetadata.image from the first <img> tag in the body
getter/setter pairinherited-setteroverride-getter
locale String?
Default locale
getter/setter pairinherited-setteroverride-getter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
siteName String?
Get the OpengraphMetadata.siteName from the domain of the URL
getter/setter pairinherited-setteroverride-getter
title String?
Get the OpengraphMetadata.title from the <title> tag
getter/setter pairinherited-setteroverride-getter
type String?
Default type
getter/setter pairinherited-setteroverride-getter
url String?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse() OpengraphMetadata
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited