OpengraphParser class

Takes a Document and parses OpengraphMetadata from <meta property='og:*'> tags

Mixed-in types

Constructors

OpengraphParser(Document? _document)

Properties

audios List<OgAudio>
All og:audio objects with their structured properties.
no setter
description String?
Get OpengraphMetadata.description from 'og:description'
getter/setter pairinherited-setteroverride-getter
hashCode int
The hash code for this object.
no setterinherited
image String?
Get OpengraphMetadata.image from 'og:image'
getter/setter pairinherited-setteroverride-getter
images List<OgImage>
All og:image objects with their structured properties.
no setter
locale String?
Get OpengraphMetadata.locale from 'og:locale'
getter/setter pairinherited-setteroverride-getter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
siteName String?
Get OpengraphMetadata.siteName from 'og:site_name'
getter/setter pairinherited-setteroverride-getter
structuredTags Map<String, List<String>>
Vertical tags (article:author, article:tag, book:isbn…), with repeated properties accumulated in document order.
no setter
title String?
Get OpengraphMetadata.title from 'og:title'
getter/setter pairinherited-setteroverride-getter
type String?
Get OpengraphMetadata.type from 'og:type'
getter/setter pairinherited-setteroverride-getter
url String?
Get OpengraphMetadata.url from 'og:url'
getter/setter pairinherited-setteroverride-getter
videos List<OgVideo>
All og:video objects with their structured properties.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse() OpengraphMetadata
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited