opengraph library
@project : opengraph @author : Baldomero (datogedon@gmail.com) @link : https://github.com/baldomerocho/flutter_opengraph/ @Disc : a dart and flutter package to fetch and preview OpenGraph data
Classes
- FaviconParser
-
Extracts the favicon declared by a
Documenthead. - HtmlMetaParser
-
Takes a
Documentand parses OpengraphMetadata from<meta>,<title>and<img>tags - JsonLdParser
-
Takes a
Documentand parses OpengraphMetadata fromjson-lddata in<script> - OgAudio
-
An
og:audioobject with its structured properties. - OgImage
-
An
og:imageobject with its structured properties. - OgMedia
- Common fields of every OpenGraph media object.
- OgVideo
-
An
og:videoobject with its structured properties. - OpengraphCache
- In-memory cache for opengraph_fetch results.
- OpenGraphConfiguration
- OpenGraphEntity
- OpenGraphEntity represents the OpenGraph protocol Properties:
- OpengraphFetch
- OpengraphMetadata
- Container class for Metadata
- OpengraphMetadataAdapter
- Adapter to convert between OpengraphMetadata and OpenGraphEntity
- OpengraphMetadataParser
-
Does Works with
BaseOpengraphParser - OpengraphParser
-
Takes a
Documentand parses OpengraphMetadata from<meta property='og:*'>tags - OpengraphPreview
- A widget that fetches and displays OpenGraph data
- OpenGraphRequest
- OpenGraphRequest is a singleton class that fetches OpenGraph data from the given URL
- OpenGraphRequestInterface
- Interface for OpenGraphRequest
- TwitterCardParser
-
Takes a
Documentand parses OpengraphMetadata from<meta property='twitter:*'>tags - WidgetOpenGraph
- WidgetOpenGraph Widget Internal widget to show the OpenGraphEntity data This widget is used by OpenGraphPreview
Enums
- OpenGraphLayout
- How the preview card arranges its image and texts.
Mixins
Functions
-
opengraph_fetch(
String url, {bool throwOnError = false, Map< String, String> ? headers, Duration? maxAge}) → Future<OpenGraphEntity?> - Fetch OpenGraph data from a URL and return it as an OpenGraphEntity
-
opengraph_fetch_raw(
String url) → Future - Fetch OpenGraph data from a URL and return the raw metadata