OgMedia class abstract
Common fields of every OpenGraph media object.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secureUrl → String?
-
og:*:secure_url— https variant when the page declares one.final - type → String?
-
og:*:type— MIME type, e.g.image/jpegorvideo/mp4.final - url → String
-
Absolute URL of the media (relative URLs are resolved by the parser).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited